DartSha512 class

Sha512 implemented with package:crypto (a package by Google).

For examples and more information about the algorithm, see documentation for the class Sha512.

Inheritance
Implemented types
Mixed-in types

Constructors

DartSha512()
const

Properties

blockLengthInBytes → int
The internal block size in bytes. This information is required by some algorithms such as Hmac.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hashLengthInBytes → int
Digest size in bytes.
no setterinherited
impl → Hash
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hash(List<int> input) → Future<Hash>
Creates a combined hash code for a number of objects.
inherited
hashSync(List<int> data) → Hash
Synchronous version of hash.
inherited
newHashSink() → DartHashSink
Constructs a sink for hashing chunks.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toSync() → DartHashAlgorithm
For synchronous computations, returns a pure Dart implementation of the hash algorithm.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited